import {DataRectangle} from "@/types";
import {DeepReadonly} from "vue";

const areDifferent = (vModel: DataRectangle[][], storeModel: DeepReadonly<DataRectangle[][]>) => {
    // If the lengths are different, the arrays are different
    if (vModel.length !== storeModel.length) {
        return true
    }

    let isDifferent = false
    // Iterate over the vModel  (outer; represents pages) array
    for (const vPageModel of vModel) {
        // Iterate over the  vModel (inner; represents a page of DataRectangles) array
        for (const dataRectangle of vPageModel) {
            // In the storeModel, attempt to find the same DataRectangle. Requires searching the inner array
            const storeModelElement = storeModel.find((storePageModel) =>
                storePageModel.find((element) => {
                    const dataRectangleKeys = Object.keys(dataRectangle)
                    const elementKeys = Object.keys(element)
                    // If the keys are different, the objects are different
                    if (dataRectangleKeys.length !== elementKeys.length) {
                        return false
                    }
                    // If the keys are the same, check the values
                    for (const key of dataRectangleKeys) {
                        if (dataRectangle[key] !== element[key]) {
                            return false
                        }
                    }
                    // If the keys and values are the same, the objects are the same
                    return true
                }))
            if (storeModelElement) {
                // If the element is found, it means the elements are identical. Continue
                continue
            }
            // The element was not found, so the objects are different
            isDifferent = true
        }
    }
    return isDifferent
}

export default function () {
    return {
        areDifferent,
    }
}
