import {DataRectangle} from "@/types";
import {readonly, ref} from "vue";

/**
 * Define our state
 *
 * This state is mutable in the function below, but if we pass it to the component without `toRefs` it will not mutate.
 */
const markerModel = ref<DataRectangle[][]>([])
const isDrawing = ref(false)

const resetModelPage = (pageNumber: number) => {
    if (markerModel.value.length < pageNumber) {
        return
    }
    markerModel.value[pageNumber - 1] = [];
}

const setModel = (items: DataRectangle[][]) => {
    markerModel.value = []
    for (const page of items) {
        const pageItems: DataRectangle[] = []
        for (const dataRectangle of page) {
            pageItems.push({...dataRectangle})
        }
        markerModel.value.push(pageItems)
    }
}

const addToModel = (pageNumber: number, ...items: DataRectangle[]) => {
    if (markerModel.value.length < pageNumber) {
        for (let i = markerModel.value.length; i < pageNumber; i++) {
            markerModel.value.push([])
        }
    }

    items = items.reverse().filter((drawRectangle, index, self) =>
        index === self.findIndex(rect => rect.uid === drawRectangle.uid)
    ).reverse()

    markerModel.value[pageNumber - 1].push(...items)
}

const setIsDrawing = (value: boolean) => isDrawing.value = value

export default () => {
    /**
     * Return the state as a `reference` to make it mutable.
     */
    return {
        isDrawing: readonly(isDrawing),
        markerModel: readonly(markerModel),
        addToModel,
        resetModelPage,
        setIsDrawing,
        setModel,
    }
}
